@@ -1,7 +1,7 @@
 """Init script"""
 
 """
-Copyright (c) 2020, EPFL/Blue Brain Project
+Copyright (c) 2022, EPFL/Blue Brain Project
 
  This file is part of BluePyEfe <https://github.com/BlueBrain/BluePyEfe>
 
@@ -20,8 +20,6 @@ Copyright (c) 2020, EPFL/Blue Brain Project
 """
 
 from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
 
-from bluepyefe.extractor import *  # NOQA
-from bluepyefe.tools import *  # NOQA
+__version__ = get_versions()["version"]
+del get_versions
