@@ -293,26 +293,31 @@ class Recording(object):
         if efel_settings is not None:
             tmp_settings.update(efel_settings)
 
-        # TODO: find a solution that handles negative Traces
-        # if tmp_settings.get("Threshold", None) is None:
-        #     idx_ton = self.ms_to_index(self.ton)
-        #     idx_toff = self.ms_to_index(self.toff)
-        #     step_voltage = numpy.median(self.voltage[idx_ton:idx_toff])
-        #     thresh = step_voltage + offset_voltage
-        #     tmp_settings["Threshold"] = thresh
-        #     efel_vals = self.call_efel(['peak_time'], tmp_settings)
-        #     self.peak_time = efel_vals[0]['peak_time']
-        #     self.auto_threshold = thresh
-        #
-        # else:
-        efel_vals = self.call_efel(['peak_time'], tmp_settings)
-        self.peak_time = efel_vals[0]['peak_time']
+        # If the setting Threshold is not provided, tries to find it
+        if tmp_settings.get("Threshold", None) is None:
+            idx_ton = self.ms_to_index(self.ton)
+            idx_toff = self.ms_to_index(self.toff)
+            step_voltage = numpy.median(self.voltage[idx_ton:idx_toff])
+            base_voltage = numpy.median(self.voltage[:idx_ton])
+            if base_voltage > step_voltage:
+                thresh = base_voltage + offset_voltage
+            else:
+                thresh = step_voltage + offset_voltage
+            tmp_settings["Threshold"] = thresh
+            efel_vals = self.call_efel(['peak_time'], tmp_settings)
+            self.peak_time = efel_vals[0]['peak_time']
+            # The threshold cannot be lower than the base voltage (handles the case
+            # where the step is hyperpolarizing)
+            self.auto_threshold = numpy.clip(thresh, base_voltage + offset_voltage, 50.)
 
-        # if self.spikecount == 0 and numpy.max(self.voltage) > tmp_settings["Threshold"]:
-        #     logger.warning(
-        #         f"No spikes were detected in recording {self.files} but the "
-        #         "voltage goes higher than the spike detection threshold."
-        #     )
+        else:
+            self.peak_time = self.call_efel(['peak_time'], tmp_settings)[0]['peak_time']
+
+        if self.spikecount == 0 and numpy.max(self.voltage) > tmp_settings["Threshold"]:
+            logger.warning(
+                f"No spikes were detected in recording {self.files} but the "
+                "voltage goes higher than the spike detection threshold."
+            )
 
     def in_target(self, target, tolerance, absolute_amplitude=False):
         """Returns a boolean. True if the amplitude of the eCode is close to
@@ -357,15 +362,15 @@ class Recording(object):
         axis_current.set_title(title, size="x-small")
 
         gen_t, gen_i = self.generate()
-        axis_current.plot(self.t, self.current, c="C0")
-        axis_current.plot(gen_t, gen_i, c="C1", ls="--")
-        axis_voltage.plot(self.t, self.voltage, c="C0")
+        axis_current.plot(self.t, self.current, c="C0", lw=0.8)
+        axis_current.plot(gen_t, gen_i, c="C1", ls="--", lw=0.8)
+        axis_voltage.plot(self.t, self.voltage, c="C0", lw=0.8)
 
         if self.peak_time is not None:
             max_v = numpy.max(self.voltage)
             for pt in self.peak_time:
                 axis_voltage.plot(
-                    [pt, pt], [max_v - 30., max_v + 10.], c="C3", ls="--", lw=0.7
+                    [pt, pt], [max_v + 5, max_v + 15], c="C3", ls="-", lw=0.5
                 )
 
         if display_xlabel:
